#
# spec file for package python-extra-platforms
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-extra-platforms
Version:        3.1.0
Release:        1.1
Summary:        Detect platforms and group them by family
License:        GPL-2.0-or-later
URL:            https://github.com/kdeldycke/extra-platforms
Source:         https://files.pythonhosted.org/packages/source/e/extra-platforms/extra_platforms-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.11}
BuildRequires:  %{python_module boltons >= 25.0.0}
BuildRequires:  %{python_module distro >= 1.9.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 8.3.1}
BuildRequires:  %{python_module pytest-randomly >= 3.16.0}
BuildRequires:  %{python_module pytest-xdist >= 3.6.1}
BuildRequires:  %{python_module requests >= 2.32.3 with %python-requests < 2.33}
# /SECTION
BuildRequires:  fdupes
Requires:       python-boltons >= 25.0.0
Requires:       python-distro >= 1.9.0
BuildArch:      noarch
%python_subpackages

%description
Detect platforms and group them by family

%prep
%autosetup -p1 -n extra_platforms-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# remove coverage configuration
sed -i '/cov=/d' pyproject.toml
sed -i '/cov-report=/d' pyproject.toml
sed -i '/--cov-branch/d' pyproject.toml
sed -i '/--cov-precision=2/d' pyproject.toml
# do not run tests that try to connect to websites
rm -f tests/test_platform_data.py
%pytest

%files %{python_files}
%{python_sitelib}/extra_platforms
%{python_sitelib}/extra_platforms-%{version}.dist-info

%changelog
* Wed Mar  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 3.1.0:
  * Allow platform ID membership test on groups.
  * Add items() method to Group.
  * Allow None values in nested references to platforms and groups.
  * Keep initial order of data from platforms_from_ids() and
    groups_from_ids() results.
  * Allow arbitrary arguments number in Group._extract_platforms().
* Wed Mar  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 3.0.0:
  * Allow set operations to resolve group and Platform IDs.
  * Make resolution of platform and group IDs case-insensitive.
  * Only runs website tests on Linux to prevent DOSing them.
  * Drop supports for Python 3.10.
  * Remove tomli dependency.
* Thu Feb 20 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 2.1.0:
  * Add new platforms_from_ids and groups_from_ids methods to
    retrieve platforms and groups from a collection of IDs.
  * Allow a platform to be fetched by its ID from a group with the
    group[platform_id] item getter syntax.
  * Add new ALL_PLATFORM_IDS, ALL_GROUP_IDS and ALL_IDS constants.
  * Removes ALL_OS_LABELS.
  * Add windows-2025 to the test matrix.
  * Mark Python 3.14 tests as stable.
* Fri Jan  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 2.0.0:
  * Add support for Nobara detection.
  * Fix current_os() to always return a single platform. Closes
    [#158].
  * Add new current_platforms() method to return all platforms
    matching the current environment.
  * Generate a pair of Pytest @skip_<id>/@unless_<id> decorators
    for each platform and group.
  * Change all group membership check utilities to be functions
    instead of variables. You now have to call is_<group_id>()
    instead of is_<group_id>.
  * Cache the result of is_<group_id>() group membership check
    utilities.
  * Do not call all detection heuristics on module import. Instead,
    call them lazily when needed.
  * Make URLs required on all platforms.
  * Invite users in error messages and logs to contribute back
    edge-cases to improve detection heuristics.
  * Upload test results to coverage.
* Tue Dec  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.7.0:
  * Display the hierarchy of non-overlapping groups as a mindmap.
  * Add URL on all platforms.
  * Add support for openSUSE Tumbleweed detection. Closes #133.
  * Do not allow icons on platforms and groups to be empty.
  * Run tests in parallel to speed up CI.
* Thu Nov 28 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- enable builds for python3.13
* Wed Nov 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package python-extra-platforms, required by
  python-click-extra
